@@ -92,6 +92,10 @@ data = {
     ),
     "formatter_class": argparse.RawDescriptionHelpFormatter,
     "arguments": [
+        {
+            "name": "--config",
+            "help": "the path of configuration file",
+        },
         {"name": "--debug", "action": "store_true", "help": "use debug mode"},
         {
             "name": ["-n", "--name"],
@@ -150,6 +154,12 @@ data = {
                         "action": "store_true",
                         "help": "Tell the command to automatically stage files that have been modified and deleted, but new files you have not told Git about are not affected.",
                     },
+                    {
+                        "name": ["-l", "--message-length-limit"],
+                        "type": int,
+                        "default": 0,
+                        "help": "length limit of the commit message; 0 for no limit",
+                    },
                 ],
             },
             {
@@ -534,9 +544,7 @@ def parse_no_raise(comma_separated_no_raise: str) -> list[int]:
 
 
 def main():
-    conf = config.read_cfg()
     parser = cli(data)
-
     argcomplete.autocomplete(parser)
     # Show help if no arg provided
     if len(sys.argv) == 1:
@@ -576,6 +584,11 @@ def main():
         extra_args = " ".join(unknown_args[1:])
         arguments["extra_cli_args"] = extra_args
 
+    if args.config:
+        conf = config.read_cfg(args.config)
+    else:
+        conf = config.read_cfg()
+
     if args.name:
         conf.update({"name": args.name})
     elif not args.name and not conf.path:
